==> xmgfv1.9.1.tar.gz: xmgf/inc/Disp3DGF.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
#include <X11/Xlib.h>
#include <X11/StringDefs.h>
#include <X11/Intrinsic.h>

typedef struct _appres {
  char           *iconGeometry;
  int             XmgfWidth;
  int             XmgfHeight;
  int             XmgfSmallWidth;
  int		  XmgfSmallIconWidth;
  int             XmgfSmallHeight;
  Pixel           LineButtColor;
  Pixel           LineThickColor;
  Pixel           WarningBitmapfg;
  Pixel           WarningBitmapbg;
  Pixel           AboutfgColor;
  Pixel           AboutbgColor;
  Pixel 	  IconFGColour;
  Pixel 	  IconBGColour;
  Pixel		  IconSFGColour;
  Pixel		  IconSBGColour;
  String          PrinterName;
  String          CompressCommand;
  String          GZipCommand;
  String          RemoveCommand;
  String          GFDir;
  String          PGMDir;
  String          POSTDir;
  String          EPSDir;
  String          RAYDir;
  String          PARMDir;
  String          PPMDir;
  String          GIFDir;
  String          XBMDir;
  String          PBMDir;
  String          IMGDir;
  String          RASDir;
  String          FIGDir;
  String          IMPORTDir;
  String          CMAPDir;
  String          MIFDir;
  String          ANIMDir;
  String          off2gf;
  String          nff2gf;
  String          ray2gf;
  String          sla2gf;
  String          obj2gf;
  String          dxf2gf;
  String          igrip2gf;
  String          minicad2gf;
  String	  XMgfVersion;
  String	  XMgfRelease;
  String	  XMgfRelDate;
}               appresStruct, *appresPtr;
extern appresStruct    appres;
extern XtResource application_resources[];
extern XrmOptionDescRec options[];

#ifndef _NO_PROTO
int             Display3DGF (void);
XImage         *CreateDefaultImage (char *bits, int width, int height);
void            BusyXmgf (int flag);
void            BusyCursor (void);
void            DoneCursor (void);
#else
int             Display3DGF ();
XImage         *CreateDefaultImage ();
void            BusyXmgf ();
void            BusyCursor ();
void            DoneCursor ();
#endif

==> xmgfv2.4.tar.gz: xmgf/inc/Disp3DGF.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
#include <X11/Xlib.h>
#include <X11/StringDefs.h>
#include <X11/Intrinsic.h>

typedef struct _appres {
  char           *iconGeometry;
  int             XmgfWidth;
  int             XmgfHeight;
  int             XmgfSmallWidth;
  int		  XmgfSmallIconWidth;
  int             XmgfSmallHeight;
  Pixel           LineButtColor;
  Pixel           LineThickColor;
  Pixel           WarningBitmapfg;
  Pixel           WarningBitmapbg;
  Pixel           AboutfgColor;
  Pixel           AboutbgColor;
  Pixel 	  IconFGColour;
  Pixel 	  IconBGColour;
  Pixel		  IconSFGColour;
  Pixel		  IconSBGColour;
  String          PrinterName;
  String          CompressCommand;
  String          GZipCommand;
  String          RemoveCommand;
  String          CopyCommand;
  String          GFDir;
  String          PGMDir;
  String          POSTDir;
  String          EPSDir;
  String          RAYDir;
  String          PARMDir;
  String          PPMDir;
  String          GIFDir;
  String          XBMDir;
  String          PBMDir;
  String          IMGDir;
  String          RASDir;
  String          FIGDir;
  String          IMPORTDir;
  String          CMAPDir;
  String          MIFDir;
  String          ANIMDir;
  String          PCXDir;
  String          PICTDir;
  String          off2gf;
  String          nff2gf;
  String          ray2gf;
  String          sla2gf;
  String          obj2gf;
  String          dxf2gf;
  String          igrip2gf;
  String          minicad2gf;
  String	  XMgfVersion;
  String	  XMgfRelease;
  String	  XMgfRelDate;
  String	  HelpFile;
  String	  HelpDir;
  String	  MosaicCmd;
}               appresStruct, *appresPtr;
extern appresStruct    appres;
extern XtResource application_resources[];
extern XrmOptionDescRec options[];

#ifndef _NO_PROTO
int             Display3DGF (void);
XImage         *CreateDefaultImage (char *bits, int width, int height);
void            BusyXmgf (int flag);
void            BusyCursor (void);
void            DoneCursor (void);
#else
int             Display3DGF ();
XImage         *CreateDefaultImage ();
void            BusyXmgf ();
void            BusyCursor ();
void            DoneCursor ();
#endif
